summaryrefslogtreecommitdiffstats
path: root/chrome/browser/ui/cocoa/browser_window_controller.mm
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/ui/cocoa/browser_window_controller.mm')
-rw-r--r--chrome/browser/ui/cocoa/browser_window_controller.mm4
1 files changed, 3 insertions, 1 deletions
diff --git a/chrome/browser/ui/cocoa/browser_window_controller.mm b/chrome/browser/ui/cocoa/browser_window_controller.mm
index 8d62a40..90bb372 100644
--- a/chrome/browser/ui/cocoa/browser_window_controller.mm
+++ b/chrome/browser/ui/cocoa/browser_window_controller.mm
@@ -2016,8 +2016,10 @@ willAnimateFromState:(bookmarks::VisualState)oldState
[self setPresentationModeInternal:YES forceDropdown:YES];
[self releaseBarVisibilityForOwner:self withAnimation:YES delay:YES];
// Since -windowDidEnterFullScreen: won't be called in the
// fullscreen --> presentation mode case, manually show the exit bubble.
[self showFullscreenExitBubbleIfNecessary];
+ browser_->WindowFullscreenStateChanged();
} else {
// If not in fullscreen mode, trigger the Lion fullscreen mode machinery.
// Presentation mode will automatically be enabled in
@@ -2016,8 +2016,10 @@ willAnimateFromState:(bookmarks::VisualState)oldState
[self releaseBarVisibilityForOwner:self withAnimation:YES delay:YES];
// Since -windowDidEnterFullScreen: won't be called in the
- // fullscreen --> presentation mode case, manually show the exit bubble.
+ // fullscreen --> presentation mode case, manually show the exit bubble
+ // and notify the change happened with WindowFullscreenStateChanged().
[self showFullscreenExitBubbleIfNecessary];